<?php


/**
 * Enqueue styles and scripts.
 */
function purefit_enqueue_css_and_js() {

    /*
     * Load Google fonts.
     * User can customized this default fonts from theme options
     */
    function purefit_fonts_url() {
        $fonts_url = '';
        $fonts     = [];
        $subsets   = 'latin,latin-ext';

        if ( 'off' !== _x( 'on', 'Poppins: on or off', 'purefit' ) ) {
            $fonts[] = 'Poppins:300,400,500,600,700';
        }

        if ( 'off' !== _x( 'on', 'Chakra Petch: on or off', 'purefit' ) ) {
            $fonts[] = 'Chakra Petch:300,400,500,600,700';
        }

        if ( $fonts ) {
            $fonts_url = add_query_arg( array(
                'family' => urlencode( implode( '|', $fonts ) ),
                'subset' => urlencode( $subsets ),
            ), 'https://fonts.googleapis.com/css' );
        }

        return esc_url_raw( $fonts_url );
    }

    wp_enqueue_style( 'purefit-googlefonts', purefit_fonts_url(), [], null );

    // Enqueue Style
    wp_enqueue_style( 'bootstrap', get_theme_file_uri( 'assets/css/bootstrap.min.css' ), array(), '5.0.', 'all' );

    wp_enqueue_style( 'font-awesome-5', get_theme_file_uri( 'assets/css/fontawesome.css' ), array(), '5.13.0', 'all' );
    
    wp_enqueue_style( 'e-animations', get_theme_file_uri( 'assets/css/animate.css' ), array(), '3.5.1', 'all' );

    wp_enqueue_style( 'swiper-purefit', get_theme_file_uri( 'assets/css/swiper.min.css' ), array(), '6.6.1', 'all' );

    wp_enqueue_style( 'magnific-popup', get_theme_file_uri( 'assets/css/magnific-popup.css' ), array(), '3.1.9', 'all' );

    wp_enqueue_style( 'purefit-core', get_theme_file_uri( 'assets/css/purefit-core.css' ), array(), PUREFIT_VERSION, 'all' );

    wp_enqueue_style( 'purefit-main', get_theme_file_uri( 'assets/css/main.css' ), array(), PUREFIT_VERSION, 'all' );

    wp_enqueue_style( 'purefit-style', get_stylesheet_uri(), array(), PUREFIT_VERSION, 'all' );

    if ( class_exists('WooCommerce') ) {
        wp_enqueue_style( 'woocommerce-style', get_template_directory_uri() . '/woocommerce/woocommerce.css' );
    }
    // Enqueue script

    wp_enqueue_script( 'bootstrap', get_theme_file_uri( 'assets/js/bootstrap.bundle.min.js' ), array( 'jquery' ), '5.0.0', true );

    wp_enqueue_script( 'swiper-slider', get_theme_file_uri( 'assets/js/swiper.min.js' ), array( 'jquery' ), '6.7.0', true );

    wp_enqueue_script( 'wow', get_theme_file_uri( 'assets/js/wow.min.js' ), array( 'jquery' ), '1.1.3', true );

    wp_enqueue_script( 'magnific-popup', get_theme_file_uri( 'assets/js/jquery.magnific-popup.min.js' ), array( 'jquery' ), '1.1.0', true );

    wp_enqueue_script( 'touchspin', get_theme_file_uri( 'assets/js/touchspin.js' ), array( 'jquery' ), '1.0.0', true );

    wp_enqueue_script( 'easing', get_theme_file_uri( 'assets/js/jquery.easing.js' ), array( 'jquery' ), '1.0.0', true );

    wp_enqueue_script( 'scrollspy', get_theme_file_uri( 'assets/js/scrollspy.js' ), array( 'jquery' ), '1.0.0', true );

    wp_enqueue_script( 'purefit-main', get_theme_file_uri( 'assets/js/main.js' ), array( 'jquery' ), PUREFIT_VERSION, true );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
}

add_action( 'wp_enqueue_scripts', 'purefit_enqueue_css_and_js' );

/**
 * Enqueue Backend Styles And Scripts.
 **/

function purefit_backend_css_js( $screen ) {

    if ( $screen == "widgets.php" ) {
        wp_enqueue_media();
        wp_enqueue_script( 'purefit-media-upload', get_theme_file_uri( 'assets/js/media-upload.js' ), array( 'jquery' ), '1.0.0', true );
    }
}

add_action( 'admin_enqueue_scripts', 'purefit_backend_css_js' );