<?php

/**
 * Elementor Single Widget
 * @package purefit-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Cresta_Blog_V2 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-blog-v2';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Blog V2', 'purefit-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'purefit-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['purefit_widgets'];
    }

    protected function register_controls()
    {

        $this->start_controls_section(
            'post_option',
            [
                'label' => esc_html__('Post Option', 'purefit-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'post_order',
            [
                'label' => esc_html__('Post Order', 'purefit-core'),
                'type' => Controls_Manager::SELECT,
                'default' => 'ASC',
                'options' => [
                    'ASC' => esc_html__('Ascending', 'purefit-core'),
                    'DESC' => esc_html__('Descending', 'purefit-core'),
                ],
            ]
        );

        $this->add_control(
            'post_per_page',
            [
                'label' => __('Posts Per Page', 'purefit-core'),
                'type' => Controls_Manager::NUMBER,
                'min' => 1,
                'default' => 5,
            ]
        );
        $this->add_control(
            'post_categories',
            [
                'type' => Controls_Manager::SELECT2,
                'label' => esc_html__('Select Categories', 'purefit-core'),
                'options' => purefit_blog_category(),
                'label_block' => true,
                'multiple' => true,
            ]
        );
        $this->add_control(
            'title_length',
            [
                'label' => __('Title Length', 'purefit-core'),
                'type' => Controls_Manager::NUMBER,
                'step' => 1,
                'default' => 12,
            ]
        );
        $this->add_control(
            'button_label', [
                'label' => esc_html__('Readmore Button', 'purefit-core'),
                'default' => esc_html__('Read More', 'purefit-core'),
                'type' => Controls_Manager::TEXT,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'post_style',
            [
                'label' => esc_html__('Post Style', 'purefit-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'date-c',
            [
                'label' => esc_html__('Date Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog2 .xb-item--date' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'date_border_c',
            [
                'label' => esc_html__('Border Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog2 .xb-item--body' => 'border-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'date_typography',
                'selector' => '{{WRAPPER}} .xb-blog2 .xb-item--date',
            ]
        );
        $this->add_control(
            'cat_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'cat-c',
            [
                'label' => esc_html__('Category Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog2 .xb-item--cat' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'cat_typography',
                'selector' => '{{WRAPPER}} .xb-blog2 .xb-item--cat',
            ]
        );

        $this->add_control(
            'p_title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'p-title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog2 .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p_title_typography',
                'selector' => '{{WRAPPER}} .xb-blog2 .xb-item--title',
            ]
        );
        $this->add_control(
            'readmore_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'p-readmore-c',
            [
                'label' => esc_html__('Readmore Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog2 .xb-item--link' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'p-readmore-hover-c',
            [
                'label' => esc_html__('Readmore Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-blog2 .xb-item--link' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'p_readmore_typography',
                'selector' => '{{WRAPPER}} .xb-blog2 .xb-item--link',
            ]
        );
        $this->end_controls_section();


    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $args = array(
            'post_type' => 'post',
            'posts_per_page' => !empty($settings['post_per_page']) ? $settings['post_per_page'] : 1,
            'post_status' => 'publish',
            'ignore_sticky_posts' => 1,
            'order' => $settings['post_order'],
        );
        if (!empty($settings['post_categories'])) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }

        $query = new \WP_Query($args);
        ?>

        <div class="blog-slider swiper-container">
            <div class="swiper-wrapper">
                <?php
                if ($query->have_posts()) {
                    while ($query->have_posts()) {
                        $query->the_post();
                        $categories = get_the_terms(get_the_ID(), 'category');
                        ?>
                        <div class="swiper-slide xb-blog2 xb-hover-zoom">
                            <?php if (has_post_thumbnail()) : ?>
                                <div class="xb-item--img">
                                    <a href="<?php the_permalink(); ?>"><?php the_post_thumbnail('purefit-blog'); ?></a>
                                </div>
                            <?php endif; ?>
                            <div class="xb-item--holder ul_li mt-25">
                                <h3 class="xb-item--date"><?php echo get_the_date('j'); ?> <br><span><?php echo get_the_date('M'); ?></span></h3>
                                <div class="xb-item--body">
                                    <?php
                                    $categories = get_the_category();
                                    if (!empty($categories)) {
                                        echo '<a class="xb-item--cat" href="' . esc_url(get_category_link($categories[0]->term_id)) . '">' . esc_html($categories[0]->name) . '</a>';
                                    }
                                    ?>
                                    <h2 class="xb-item--title border-effect"><a href="<?php the_permalink(); ?>"><?php echo wp_trim_words(get_the_title(), $settings['title_length'], ''); ?></a></h2>
                                    <a class="xb-item--link xb-right-link" href="<?php the_permalink(); ?>"><?php echo esc_html($settings['button_label']); ?> <span><svg
                                                    width="31" height="16" viewBox="0 0 31 16" fill="none"
                                                    xmlns="http://www.w3.org/2000/svg">
                                        <path d="M30.7071 8.7076C31.0976 8.31707 31.0976 7.68391 30.7071 7.29338L24.3431 0.929423C23.9526 0.538898 23.3195 0.538898 22.9289 0.929422C22.5384 1.31995 22.5384 1.95311 22.9289 2.34364L28.5858 8.00049L22.9289 13.6573C22.5384 14.0479 22.5384 14.681 22.9289 15.0716C23.3195 15.4621 23.9526 15.4621 24.3431 15.0716L30.7071 8.7076ZM-8.74228e-08 9.00049L30 9.00049L30 7.00049L8.74228e-08 7.00049L-8.74228e-08 9.00049Z"
                                              fill="white"/>
                                      </svg></span></a>
                                </div>
                            </div>
                        </div>
                    <?php }
                    wp_reset_query();
                } ?>
            </div>
        </div>
        <?php
    }


}


Plugin::instance()->widgets_manager->register(new Cresta_Blog_V2());