<?php

/**
 * Elementor Single Widget
 * @package purefit-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Purefit_FAQ extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-faq';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('FAQ', 'purefit-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'purefit-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['purefit_widgets'];
    }


    protected function register_controls()
    {


        $this->start_controls_section(
            'faq_option',
            [
                'label' => esc_html__('FAQ', 'purefit-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'active',
            [
                'label' => esc_html__('Active', 'xpress-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'xpress-core'),
                'label_off' => esc_html__('Hide', 'xpress-core'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $repeater->add_control(
            'title', [
                'label' => esc_html__('Title', 'xpress-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'content', [
                'label' => esc_html__('Content', 'xpress-core'),
                'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
            ]
        );

        $this->add_control(
            'faqs',
            [
                'label' => esc_html__('Add Faq Item', 'xpress-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ],
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'faq_style',
            [
                'label' => esc_html__('Style', 'purefit-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'ftitle-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .accordion_box .block .acc-btn' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .accordion_box .block .acc-btn .arrow::before' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'title_bg-c',
            [
                'label' => esc_html__('Background Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-accordion .block' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'ftitle_typography',
                'selector' => '{{WRAPPER}} .accordion_box .block .acc-btn',
            ]
        );
        $this->add_control(
            'f_content_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'fcontent-c',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .accordion_box .block .content p' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .accordion_box .block .content' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .accordion_box .block .content ul li' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'fcontent_typography',
                'selector' => '{{WRAPPER}} .accordion_box .block .content',
            ]
        );
        $this->add_control(
            'arrow_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'arrow_c',
            [
                'label' => esc_html__('Arrow Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-accordion .block .acc-btn .arrow' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .xb-accordion .block .acc-btn .arrow::before' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'arrow_active_c',
            [
                'label' => esc_html__('Arrow Active Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-accordion .block.active-block .acc-btn .arrow' => 'border-color: {{VALUE}}',
                    '{{WRAPPER}} .xb-accordion .block.active-block .acc-btn .arrow:before' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>

        <ul class="xb-accordion accordion_box clearfix">
            <?php foreach ($settings['faqs'] as $faq): ?>
                <li class="block accordion <?php if ('yes' == $faq['active']) {
                    echo esc_attr('active-block');
                } ?>">
                    <div class="acc-btn">
                        <?php echo esc_html($faq['title']); ?>
                        <span class="arrow"></span>
                    </div>
                    <div class="acc_body <?php if ('yes' == $faq['active']) {
                        echo esc_attr('current');
                    } ?>">
                        <div class="content">
                            <?php echo wp_kses($faq['content'], true); ?>
                        </div>
                    </div>
                </li>
            <?php endforeach; ?>
        </ul>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Purefit_FAQ());