<?php

/**
 * Elementor Single Widget
 * @package purefit-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Purefit_Pricing extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-pricing';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Pricing', 'purefit-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'purefit-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['purefit_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'purefit-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'active',
            [
                'label' => esc_html__('Active', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ovix-core'),
                'label_off' => esc_html__('No', 'ovix-core'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $this->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'shape',
            [
                'label' => esc_html__('Shape', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );
        $this->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'price',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Price', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'price_suffix',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Price Suffix', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'price_total',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Price Total', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'deactive',
            [
                'label' => esc_html__('Deactive?', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ovix-core'),
                'label_off' => esc_html__('No', 'ovix-core'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__('Icon', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );
        $repeater->add_control(
            'text',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Title', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'lists',
            [
                'label' => esc_html__('Feature List', 'purefit-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ text }}}',
            ]
        );

        $this->add_control(
            'btn_label',
            [
                'type' => Controls_Manager::TEXT,
                'label' => esc_html__('Button Label', 'purefit-core'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'btn_link',
            [
                'label' => esc_html__('Button Link', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'options' => ['url'],
                'default' => [
                    'url' => '#',
                ],
                'label_block' => true,
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Style', 'purefit-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'quote_bg-c',
            [
                'label' => esc_html__('Quote BG Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--quote' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'name_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'name-c',
            [
                'label' => esc_html__('Name Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--name' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .xb-testimonial .xb-item--name',
            ]
        );

        $this->add_control(
            'date_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'date-c',
            [
                'label' => esc_html__('Date Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--date' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'date_typography',
                'selector' => '{{WRAPPER}} .xb-testimonial .xb-item--date',
            ]
        );
        $this->add_control(
            'content_hr',
            [
                'label' => esc_html__('Content', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'content_color',
            [
                'label' => esc_html__('Content Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-testimonial .xb-item--desc' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .xb-testimonial .xb-item--desc',
            ]
        );
        $this->add_control(
            'nav_options',
            [
                'label' => esc_html__('Slider Nav Style', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'nav-bg-c',
            [
                'label' => esc_html__('Nav Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonial-slider .swiper-pagination-bullet' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $bag = PUREFIT_DIR_URL . 'assets/img/bag.svg';
        ?>

        <div class="xb-pricing <?php echo ($settings['active'] === 'yes') ? 'active' : ''; ?>">
            <div class="xb-item--head pos-rel">
                <?php if (!empty($settings['title'])): ?>
                    <h4 class="xb-item--title"><?php echo esc_html($settings['title']); ?></h4>
                <?php endif; ?>
                <?php if (!empty($settings['price'])): ?>
                    <h2 class="xb-item--price"><?php echo esc_html($settings['price']); ?><span><?php echo esc_html($settings['price_suffix']); ?></span></h2>
                <?php endif; ?>
                <?php if (!empty($settings['price_total'])): ?>
                    <h3 class="xb-item--price-sub"><?php echo esc_html($settings['price_total']); ?></h3>
                <?php endif; ?>
                <div class="xb-item--img" <?php if (!empty($settings['image']['url'])): ?>
                     style="background-image: url('<?php echo esc_url($settings['image']['url']); ?>') <?php endif; ?>"></div>
                <div class="xb-item--shape" <?php if (!empty($settings['shape']['url'])): ?>
                     style="background-image: url('<?php echo esc_url($settings['shape']['url']); ?>') <?php endif; ?>"></div>
            </div>
            <div class="xb-item--body">
                <ul class="xb-item--list list-unstyled">
                    <?php
                    foreach ($settings['lists'] as $list):
                        ?>
                        <li class="feature-list-item <?php echo ($list['deactive'] === 'yes') ? 'deactive' : ''; ?>"><?php \Elementor\Icons_Manager::render_icon($list['icon'], ['aria-hidden' => 'true']); ?><?php echo esc_html($list['text']); ?></li>
                    <?php endforeach; ?>
                </ul>
                <?php if (!empty($settings['btn_label'])): ?>
                    <div class="xb-item--btn">
                        <a class="thm-btn w-100 text-center mt-45" href="<?php echo esc_url($settings['btn_link']['url']); ?>"><img src="<?php echo esc_url($bag); ?>" alt=""><?php echo esc_html($settings['btn_label']); ?></a>
                    </div>
                <?php endif; ?>
            </div>
        </div>

        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Purefit_Pricing());