<?php

/**
 * Elementor Single Widget
 * @package purefit-core
 * @since 1.0.0
 */

namespace Elementor;

if (!defined('ABSPATH')) exit; // Exit if accessed directly.

class Purefit_Products_V3 extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Elementor widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_name()
    {
        return 'int-products-v3';
    }

    /**
     * Get widget title.
     *
     * Retrieve Elementor widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_title()
    {
        return esc_html__('Products V3', 'purefit-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Elementor widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_icon()
    {
        return 'purefit-custom-icon';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Elementor widget belongs to.
     *
     * @return array Widget categories.
     * @since 1.0.0
     * @access public
     *
     */
    public function get_categories()
    {
        return ['purefit_widgets'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'section_title_option',
            [
                'label' => esc_html__('Section Title', 'purefit-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'sub_title', [
                'label' => esc_html__('Sub Title', 'purefit-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $this->add_control(
            'title', [
                'label' => esc_html__('Title', 'purefit-core'),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'content_option',
            [
                'label' => esc_html__('Content', 'purefit-core'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new Repeater();

        $repeater->add_control(
            'select_product',
            [
                'label' => esc_html__('Select a product', 'purefit-core'),
                'type' => Controls_Manager::SELECT,
                'label_block' => true,
                'options' => $this->get_all_products(),
                'default' => 'none'
            ]
        );

        $repeater->add_control(
            'product_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __('Product Image', 'purefit-core'),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'products_lists',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => esc_html__('Section Title Style', 'purefit-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'sub-title-c',
            [
                'label' => esc_html__('Sub Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title .sub-title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'sub-title-border-c',
            [
                'label' => esc_html__('Sub Title Border Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title .sub-title::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .sec-title .sub-title::after' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'sub_title_typography',
                'selector' => '{{WRAPPER}} .sec-title .sub-title',
            ]
        );

        $this->add_control(
            'stitle-style',
            [
                'label' => esc_html__('Title Style', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'stitle-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .sec-title .title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'stitle_typography',
                'selector' => '{{WRAPPER}} .sec-title .title',
            ]
        );
        $this->add_control(
            'stitle_padding',
            [
                'label' => esc_html__('Padding', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .sec-title .title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'color_option',
            [
                'label' => esc_html__('Product Style', 'purefit-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'bg-c',
            [
                'label' => esc_html__('Background Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-product' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'padding',
            [
                'label' => esc_html__('Padding', 'ovix-core'),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em', 'rem', 'custom'],
                'selectors' => [
                    '{{WRAPPER}} .xb-product' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'title_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'title-c',
            [
                'label' => esc_html__('Title Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-product .xb-item--title' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .xb-product .xb-item--title',
            ]
        );
        $this->add_control(
            'price_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'price-c',
            [
                'label' => esc_html__('Price Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-product .xb-item--price span' => 'color: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'price_typography',
                'selector' => '{{WRAPPER}} .xb-product .xb-item--price span',
            ]
        );
        $this->add_control(
            'cart_icon_bg-c',
            [
                'label' => esc_html__('Cart Icon BG Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-product .xb-item--cart' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'cart_icon_hover_bg-c',
            [
                'label' => esc_html__('Cart Icon Hover BG Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .xb-product .xb-item--cart:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'cart_icon_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );
        $this->add_control(
            'nav_style',
            [
                'label' => esc_html__('Nav Style', 'purefit-core'),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'nav_bg-c',
            [
                'label' => esc_html__('Nav BG Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .shop-carousel .xb-swiper-arrow::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_bg_hover-c',
            [
                'label' => esc_html__('Nav Hover BG Color', 'ovix-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .shop-carousel .xb-swiper-arrow:hover::before' => 'background-color: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_icon-c',
            [
                'label' => esc_html__('Nav Icon Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .shop-carousel .xb-swiper-arrow svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );
        $this->add_control(
            'nav_icon_hover-c',
            [
                'label' => esc_html__('Nav Icon Hover Color', 'purefit-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .shop-carousel .xb-swiper-arrow:hover svg path' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }

    // Get Product Lists
    public function get_all_products()
    {
        $products = wc_get_products([
            'status' => 'publish',
            'orderby' => 'name',
            'order' => 'DESC',
            'limit' => -1,
        ]);

        $options = ['none' => 'None'];
        foreach ($products as $product) {
            $options[$product->get_id()] = $product->get_name();
        }

        return $options;
    }


    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $bag = PUREFIT_DIR_URL . 'assets/img/bag.svg';
        ?>

        <section class="shop z-3 pos-rel">
            <div class="container">
                <div class="ul_li_between mb-25">
                    <div class="sec-title sec-title--white sec-title--two mb-30">
                        <?php if (!empty($settings['sub_title'])): ?>
                            <span class="sub-title"><?php echo esc_html($settings['sub_title']); ?></span>
                        <?php endif;
                        if (!empty($settings['title'])): ?>
                            <h2 class="title"><?php echo wp_kses($settings['title'], true); ?></h2>
                        <?php endif; ?>
                    </div>
                    <div class="shop-carousel ul_li">
                        <div class="xb-swiper-arrow xb-swiper-arrow-prev">
                            <svg width="37" height="24" viewBox="0 0 37 24" fill="none"
                                 xmlns="http://www.w3.org/2000/svg">
                                <path d="M0.892464 13.0607C0.306679 12.4749 0.306679 11.5251 0.892464 10.9393L10.4384 1.3934C11.0242 0.807611 11.9739 0.807611 12.5597 1.3934C13.1455 1.97919 13.1455 2.92893 12.5597 3.51472L4.07444 12L12.5597 20.4853C13.1455 21.0711 13.1455 22.0208 12.5597 22.6066C11.9739 23.1924 11.0242 23.1924 10.4384 22.6066L0.892464 13.0607ZM36.9531 13.5H1.95312V10.5H36.9531V13.5Z"
                                      fill="#2F2F29"/>
                            </svg>
                        </div>
                        <div class="xb-swiper-arrow xb-swiper-arrow-next">
                            <svg width="37" height="24" viewBox="0 0 37 24" fill="none"
                                 xmlns="http://www.w3.org/2000/svg">
                                <path d="M36.0607 13.0607C36.6464 12.4749 36.6464 11.5251 36.0607 10.9393L26.5147 1.3934C25.9289 0.807611 24.9792 0.807611 24.3934 1.3934C23.8076 1.97919 23.8076 2.92893 24.3934 3.51472L32.8787 12L24.3934 20.4853C23.8076 21.0711 23.8076 22.0208 24.3934 22.6066C24.9792 23.1924 25.9289 23.1924 26.5147 22.6066L36.0607 13.0607ZM0 13.5H35V10.5H0V13.5Z"
                                      fill="#2F2F29"/>
                            </svg>
                        </div>
                    </div>
                </div>
                <div class="product-slider swiper-container">
                    <div class="swiper-wrapper">
                        <?php foreach ($settings['products_lists'] as $item) :
                            $product_details = wc_get_product($item['select_product']);
                            if (empty($product_details)) {
                                return;
                            }
                            ?>
                            <div class="swiper-slide">
                                <div class="xb-product text-center pos-rel xb-hover-zoom">
                                    <div class="xb-item--img">
                                        <a href="<?php echo get_permalink($product_details->get_id()) ?>"><img
                                                    src="<?php echo esc_url($item['product_image']['url']); ?>"
                                                    alt="<?php echo esc_attr__('img', 'purefit-core') ?>"></a>
                                    </div>
                                    <div class="xb-item--holder">
                                        <h2 class="xb-item--title"><a href="<?php echo get_permalink($product_details->get_id()) ?>"><?php echo esc_html($product_details->get_name()); ?></a></h2>
                                        <h3 class="xb-item--price"><?php echo wp_kses($product_details->get_price_html(), true); ?></h3>
                                        <div class="xb-item--rating ul_li_center">
                                            <?php
                                            if ($average = $product_details->get_average_rating()) {
                                                echo '<div class="star-rating" title="' . sprintf(__('Rated %s out of 5', 'purefit-core'), $average) . '"><span style="width:' . (($average / 5) * 100) . '%"><strong itemprop="ratingValue" class="rating">' . $average . '</strong> ' . __('out of 5', 'purefit-core') . '</span></div>';
                                            } else {
                                                for ($i = 0; $i < 5; $i++) {
                                                    echo '<i class="far fa-star"></i>';
                                                }
                                            }
                                            ?>
                                            <span>(<?php echo $product_details->get_rating_count(); ?>)</span>
                                        </div>
                                    </div>
                                    <a class="xb-item--cart" href="<?php echo get_permalink($product_details->get_id()) ?>"><img src="<?php echo esc_url($bag); ?>" alt=""></a>
                                    <?php
                                    if ($product_details->get_regular_price() != '' && $product_details->get_sale_price() != '') {
                                        $percent = round((((int)$product_details->get_regular_price() - (int)$product_details->get_sale_price()) / (int)$product_details->get_regular_price()) * 100);
                                        echo '<span class="xb-item--badge">' . esc_html('-' . $percent . '%', 'woocommerce') . '</span>';
                                    }
                                    ?>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        </section>
        <?php
    }

}


Plugin::instance()->widgets_manager->register(new Purefit_Products_V3());